Index: trunk/src/tmcsim/client/CADClientView.java
===================================================================
--- trunk/src/tmcsim/client/CADClientView.java	(revision 37)
+++ trunk/src/tmcsim/client/CADClientView.java	(revision 124)
@@ -48,5 +48,5 @@
  * Main Text Area, and Footer.  User input is handled by the Command Line Pane.
  * Any commands are sent to the model which are then transmitted to the
  * CAD Simulator.  The view keeps track of current CAD Screen Number and the
  * current page being displayed on each screen.  This allows for the screen
  * refresh and cycle commands to return the screen to its previous page. 
@@ -645,8 +645,10 @@
         {
             JOptionPane.showMessageDialog(this, 
-                    "Connection to the CAD Simulator has been lost.  " +
+                    "Connection to the CAD Server has been lost.  " +
                     "Restart the CAD Client.", "Connection Error", 
                     JOptionPane.ERROR_MESSAGE); 
-            return;
+            //return;
+            // Changed to hard exit because Windows was hanging here
+            System.exit(-1);
         }
         
@@ -48,5 +48,5 @@
  * Main Text Area, and Footer.  User input is handled by the Command Line Pane.
  * Any commands are sent to the model which are then transmitted to the
- * CAD Simulator.  The view keeps track of current CAD Screen Number and the
+ * CAD Server.  The view keeps track of current CAD Screen Number and the
  * current page being displayed on each screen.  This allows for the screen
  * refresh and cycle commands to return the screen to its previous page. 
